@@ -10,7 +10,6 @@ test_publish_article = scenario(
     scenario_name='Publishing the article',
 )
 """
-
 import inspect
 from os import path as op
 
@@ -26,7 +25,8 @@ def scenario(feature_name, scenario_name):
 
     def _scenario(request):
         # Get the feature
-        feature_path = op.abspath(op.join(op.dirname(request.module.__file__), feature_name))
+        base_path = request.getfuncargvalue('pytestbdd_feature_base_dir')
+        feature_path = op.abspath(op.join(base_path, feature_name))
         feature = Feature.get_feature(feature_path)
 
         # Get the scenario
